#!/bin/sh

##############################################
# 
#  Cacko ROM Builder, v 1.5
#  Copyright (C) Cacko Team, http://cacko.biz
#
##############################################

VERSION=1.23
ZVERSION="$VERSION $NVERSION ($ZMODEL)"

echo "Building ROM $ZVERSION..."
HOME_DIR=`pwd`
BASE_DIR="$HOME_DIR/base"
BUILD_DIR="$HOME_DIR/build"

updatelink() {
    rm -rf $2
    mkdir -p $2
    if [ ! -d $1 ]; then
	return
    fi
    touch -cm $1
    cd $1
    $HOME_DIR/bin/make_sym.sh ./ $2 $3 2>/dev/null >/dev/null
}

FOLDERS="bin
lib
local
libexec
sbin
share
sharp"

echo "Build directory: " $BUILD_DIR

for folder in $FOLDERS
do
    updatelink $BUILD_DIR/root_cramfs/usr/$folder.rom $BUILD_DIR/home/root/usr/$folder /usr/$folder.rom
done

FOLDERS="bin
binlib
defconf
demo
help
i18n
lib
opera
pics
pics144
plugins
share
sounds
zone"

echo "Home/QtPalmtop directory " $BUILD_DIR

# create links fo pictures
cd $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/pics144
$HOME_DIR/bin/make_sym.sh ./ $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/pics /usr/QtPalmtop.rom/pics144 > /dev/null 2> /dev/null

#updatelink $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/pics144 $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/pics ../pics144

for folder in $FOLDERS
do
    updatelink $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/$folder $BUILD_DIR/home/QtPalmtop/$folder /usr/QtPalmtop.rom/$folder
done


updatelink $BUILD_DIR/root_cramfs/usr/sharp.rom $BUILD_DIR/home/sharp /usr/sharp.rom
updatelink $BUILD_DIR/root_jffs2/lib/modules.rom $BUILD_DIR/home/root/modules /lib/modules.rom
rm -f $BUILD_DIR/home/root/modules/$KERNEL_VERSION/modules.*
cp $BUILD_DIR/root_jffs2/lib/modules.rom/$KERNEL_VERSION/modules.* $BUILD_DIR/home/root/modules/$KERNEL_VERSION/

echo "Updating files ownership..."
chown -R root:root $BUILD_DIR/root_cramfs
chown -R root:root $BUILD_DIR/root_jffs2

chown -R root:500 $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom

#chown root:root $BUILD_DIR/root_cramfs/usr/QtPalmtop.rom/bin/quickexec

chown -R root:root $BUILD_DIR/home
chown -R root:500 $BUILD_DIR/home/QtPalmtop
chown -R 500:500 $BUILD_DIR/home/zaurus

cd $BUILD_DIR

#echo "Create cloop image..."
#dd if=/dev/zero of=usr.ext2 bs=1M count=55
#mkfs.ext2 -F usr.ext2
#mkdir temp_cloop
#mount -o loop -t ext2 usr.ext2 temp_cloop
#cp -a root_cramfs/usr/. temp_cloop
#umount temp_cloop
#rm -rf temp_cloop

#bin/create_compressed_fs usr.ext2 262144 >root_jffs2/boot/usr.ext2.cloop
#rm usr.ext2

#echo "Create cramfs image..."
cd $BUILD_DIR/root_cramfs
rm -f ../root_jffs2/boot/usr.bin
#$BUILD_DIR/bin/mkcramfs usr ../root_jffs2/boot/usr.bin
$HOME_DIR/bin/mksquashfs usr ../root_jffs2/boot/usr.bin
chmod a-x+r ../root_jffs2/boot/usr.bin

cd $BUILD_DIR

echo "CACkO Zaurus Qtopia ROM $ZVERSION \"Nastya\""> $BUILD_DIR/home/root/.buildver
echo `date` >> $BUILD_DIR/home/root/.buildver
cp -f $BUILD_DIR/home/root/.buildver $BUILD_DIR/root_jffs2/root

echo "create .home_default.tar.gz"
tar -c home > $BUILD_DIR/root_jffs2/root/.home_default.tar
rm -f $BUILD_DIR/root_jffs2/root/.home_default.tar.gz
gzip -9 $BUILD_DIR/root_jffs2/root/.home_default.tar
#mv $BUILD_DIR/root_jffs2/root/.home_default.tar.gz $BUILD_DIR/root_jffs2/root/.home_default.tgz
#bzip2 -z9 $BUILD_DIR/root_jffs2/root/.home_default.tar

echo "create .var_default.tar.gz"
tar -c var > $BUILD_DIR/root_jffs2/root/.var_default.tar
rm -f $BUILD_DIR/root_jffs2/root/.var_default.tar.gz
gzip -9 $BUILD_DIR/root_jffs2/root/.var_default.tar
#mv $BUILD_DIR/root_jffs2/root/.var_default.tar.gz $BUILD_DIR/root_jffs2/root/.var_default.tgz
#bzip2 -z9 $BUILD_DIR/root_jffs2/root/.var_default.tar

echo "create .dev_default.tar.gz"
tar -c dev > $BUILD_DIR/root_jffs2/root/.dev_default.tar
rm -f $BUILD_DIR/root_jffs2/root/.dev_default.tar.gz
gzip -9 $BUILD_DIR/root_jffs2/root/.dev_default.tar
#mv $BUILD_DIR/root_jffs2/root/.dev_default.tar.gz $BUILD_DIR/root_jffs2/root/.dev_default.tgz
#bzip2 -z9 $BUILD_DIR/root_jffs2/root/.dev_default.tar


echo "Creating initrd.bin"
cd $HOME_DIR
bin/build.sh

echo "Creating tools.jar"
cd $HOME_DIR/bin
tar -cvf tools.tar tools/bin tools/patch tools/share tools/kernel-$ZMODEL
cd $HOME_DIR

echo "Encoding updater.sh"
cd $HOME_DIR/bin
cp -f updater.sh.src updater.sh
./encsh -c updater.sh
cd $HOME_DIR

cp bin/updater.sh .
cp bin/tools.tar .

cat $BUILD_DIR/home/root/.buildver > readme.txt
cat bin/readme.txt.proto >> readme.txt
cat release-notes.txt >> readme.txt

#MAXFILESIZE=29360128
#MAXFILESIZE=28311552
MAXFILESIZE=19922944

FILESIZE=`ls -l initrd.bin | awk '{print $5}'`
echo "File size: $FILESIZE, Max: $MAXFILESIZE"
if [ "$MAXFILESIZE" -lt $FILESIZE ]; then
    echo "WARNING: File inird.bin may be too large"
fi
	      
echo "Creating $ZMODEL-Qtopia-$VERSION-lite-$NVERSION.zip..."

rm -f $ZMODEL-Qtopia-$VERSION-lite-$NVERSION.zip

zip -9 $ZMODEL-Qtopia-$VERSION-lite-$NVERSION.zip updater.sh initrd.bin tools.tar readme.txt release-notes-*.txt
md5sum $ZMODEL-Qtopia-$VERSION-lite-$NVERSION.zip > $ZMODEL-Qtopia-$VERSION-lite-$NVERSION.md5
rm tools.tar updater.sh readme.txt initrd.bin

echo "ROM $ZVERSION built successfuly..."
